@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2009, 2013, 2014 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2009-2014 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "puzzle.h"
 
@@ -23,10 +10,12 @@
 
 //-----------------------------------------------------------------------------
 
+#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
 inline uint qHash(const QPoint& key)
 {
 	return (key.x() << 16) + key.y();
 }
+#endif
 
 //-----------------------------------------------------------------------------
 
@@ -110,7 +99,7 @@ void Puzzle::shuffle(QList<QPoint>& pegs)
 bool Puzzle::findNextMove(const QPoint& start_hole, QPoint& jumped_hole, QPoint& end_hole)
 {
 	std::shuffle(m_directions.begin(), m_directions.end(), m_random);
-	for (const QPoint& direction : m_directions) {
+	for (const QPoint& direction : qAsConst(m_directions)) {
 		jumped_hole = direction + start_hole;
 		end_hole = (direction * 2) + start_hole;
 		if (isAvailable(jumped_hole) && isAvailable(end_hole)) {
@@ -133,7 +122,7 @@ QPoint Puzzle::findMoves(const QPoint& start, int loops)
 	QPoint jumped_hole, end_hole;
 	for (int i = 0; i < loops; ++i) {
 		shuffle(pegs);
-		for (const QPoint& start_hole : pegs) {
+		for (const QPoint& start_hole : qAsConst(pegs)) {
 			if (findNextMove(start_hole, jumped_hole, end_hole)) {
 				pegs.removeOne(start_hole);
 				pegs.append(jumped_hole);
