@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2009, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2009-2021 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "window.h"
 
@@ -31,21 +18,20 @@
 #include <QFormLayout>
 #include <QMenuBar>
 #include <QMessageBox>
+#include <QRandomGenerator>
+#include <QRegularExpression>
 #include <QSettings>
 #include <QSpinBox>
 #include <QToolBar>
 #include <QUndoStack>
 #include <QVBoxLayout>
 
-#include <ctime>
-#include <random>
-
 //-----------------------------------------------------------------------------
 
-Window::Window() :
-	m_seed(0),
-	m_difficulty(QSettings().value("Difficulty", 5).toInt()),
-	m_algorithm(QSettings().value("Algorithm", 1).toInt())
+Window::Window()
+	: m_seed(0)
+	, m_difficulty(QSettings().value("Difficulty", 5).toInt())
+	, m_algorithm(QSettings().value("Algorithm", 1).toInt())
 {
 	// Create board
 	QUndoStack* moves = new QUndoStack(this);
@@ -56,20 +42,20 @@ Window::Window() :
 	// Create menubar
 	QMenu* game_menu = menuBar()->addMenu(tr("&Game"));
 
-	QAction* new_action = game_menu->addAction(QIcon::fromTheme("document-new"), tr("&New"), this, SLOT(newGame()), QKeySequence::New);
-	QAction* restart_action = game_menu->addAction(QIcon::fromTheme("view-refresh"), tr("&Restart Game"), this, SLOT(restartGame()), QKeySequence::Refresh);
-	game_menu->addAction(tr("&Details"), this, SLOT(showDetails()));
+	QAction* new_action = game_menu->addAction(QIcon::fromTheme("document-new"), tr("&New"), this, &Window::newGame, QKeySequence::New);
+	QAction* restart_action = game_menu->addAction(QIcon::fromTheme("view-refresh"), tr("&Restart Game"), this, &Window::restartGame, QKeySequence::Refresh);
+	game_menu->addAction(tr("&Details"), this, &Window::showDetails);
 	game_menu->addSeparator();
-	QAction* quit_action = game_menu->addAction(QIcon::fromTheme("application-exit"), tr("Quit"), this, SLOT(close()), QKeySequence::Quit);
+	QAction* quit_action = game_menu->addAction(QIcon::fromTheme("application-exit"), tr("Quit"), this, &Window::close, QKeySequence::Quit);
 	quit_action->setMenuRole(QAction::QuitRole);
 
 	QMenu* move_menu = menuBar()->addMenu(tr("&Move"));
 
-	QAction* undo_action = move_menu->addAction(QIcon::fromTheme("edit-undo"), tr("&Undo"), moves, SLOT(undo()), QKeySequence::Undo);
+	QAction* undo_action = move_menu->addAction(QIcon::fromTheme("edit-undo"), tr("&Undo"), moves, &QUndoStack::undo, QKeySequence::Undo);
 	undo_action->setEnabled(false);
 	connect(moves, &QUndoStack::canUndoChanged, undo_action, &QAction::setEnabled);
 
-	QAction* redo_action = move_menu->addAction(QIcon::fromTheme("edit-redo"), tr("&Redo"), moves, SLOT(redo()), QKeySequence::Redo);
+	QAction* redo_action = move_menu->addAction(QIcon::fromTheme("edit-redo"), tr("&Redo"), moves, &QUndoStack::redo, QKeySequence::Redo);
 	redo_action->setEnabled(false);
 	connect(moves, &QUndoStack::canRedoChanged, redo_action, &QAction::setEnabled);
 
@@ -100,15 +86,15 @@ Window::Window() :
 
 	connect(m_colors, &QActionGroup::triggered, this, &Window::changeAppearance);
 
-	appearance_menu->addAction(tr("Custom..."), this, SLOT(changeAppearanceCustom()));
+	appearance_menu->addAction(tr("Custom..."), this, &Window::changeAppearanceCustom);
 
 	QMenu* settings_menu = menuBar()->addMenu(tr("&Settings"));
-	settings_menu->addAction(tr("Application &Language..."), this, SLOT(setLocale()));
+	settings_menu->addAction(tr("Application &Language..."), this, &Window::setLocale);
 
 	QMenu* help_menu = menuBar()->addMenu(tr("&Help"));
-	QAction* about_action = help_menu->addAction(tr("&About"), this, SLOT(about()));
+	QAction* about_action = help_menu->addAction(tr("&About"), this, &Window::about);
 	about_action->setMenuRole(QAction::AboutRole);
-	QAction* about_qt_action = help_menu->addAction(tr("About &Qt"), qApp, SLOT(aboutQt()));
+	QAction* about_qt_action = help_menu->addAction(tr("About &Qt"), qApp, &QApplication::aboutQt);
 	about_qt_action->setMenuRole(QAction::AboutQtRole);
 
 	// Create toolbar
@@ -233,7 +219,7 @@ void Window::about()
 		"<p align='center'>%6<br/><small>%7</small></p>")
 		.arg(tr("Peg-E"), QCoreApplication::applicationVersion(),
 			tr("Peg elimination game"),
-			tr("Copyright &copy; 2009-%1 Graeme Gott").arg("2020"),
+			tr("Copyright &copy; 2009-%1 Graeme Gott").arg("2021"),
 			tr("Released under the <a href=%1>GPL 3</a> license").arg("\"http://www.gnu.org/licenses/gpl.html\""),
 			tr("Uses icons from the <a href=%1>Oxygen</a> icon theme").arg("\"http://www.oxygen-icons.org/\""),
 			tr("Used under the <a href=%1>LGPL 3</a> license").arg("\"http://www.gnu.org/licenses/lgpl.html\""))
@@ -257,9 +243,9 @@ void Window::changeAppearanceCustom()
 	}
 
 	QString selected_color = color.name();
-	QList<QAction*> actions = m_colors->actions();
+	const QList<QAction*> actions = m_colors->actions();
 	for (QAction* action : actions) {
-		action->setChecked(action->data() == selected_color);
+		action->setChecked(action->data().toString() == selected_color);
 	}
 
 	m_board->setAppearance(color);
@@ -281,14 +267,15 @@ void Window::loadGame()
 	startGame(seed, difficulty, algorithm);
 
 	// Load moves
-	QRegExp parse("(-?\\d+)x(-?\\d+) to (-?\\d+)x(-?\\d+)");
-	for (const QString& move : moves) {
-		if (!parse.exactMatch(move)) {
+	const QRegularExpression parse("^(-?\\d+)x(-?\\d+) to (-?\\d+)x(-?\\d+)$");
+	for (const QString& move : qAsConst(moves)) {
+		const QRegularExpressionMatch match = parse.match(move);
+		if (!match.hasMatch()) {
 			continue;
 		}
 
-		QPoint old_hole(parse.cap(1).toInt(), parse.cap(2).toInt());
-		QPoint new_hole(parse.cap(3).toInt(), parse.cap(4).toInt());
+		QPoint old_hole(match.captured(1).toInt(), match.captured(2).toInt());
+		QPoint new_hole(match.captured(3).toInt(), match.captured(4).toInt());
 		if (m_board->isPeg(old_hole) && m_board->isHole(new_hole)) {
 			m_board->move(old_hole, new_hole);
 		} else {
@@ -302,14 +289,7 @@ void Window::loadGame()
 void Window::startGame(int seed, int difficulty, int algorithm)
 {
 	if (seed == 0) {
-#ifndef Q_OS_WIN
-		std::random_device rd;
-		std::mt19937 gen(rd());
-#else
-		std::mt19937 gen(time(0));
-#endif
-		std::uniform_int_distribution<int> dis;
-		seed = dis(gen);
+		seed = QRandomGenerator::system()->bounded(INT_MAX);
 	}
 	m_seed = seed;
 	m_difficulty = difficulty;
